"""
__init__
"""
from ezhost.BigDataArchi import BigDataArchi
from ezhost.ServerLamp import ServerLamp
from ezhost.ServerLnmp import ServerLnmp
from ezhost.ServerDjango import ServerDjango
from ezhost.ServerLnmpWordpress import ServerLnmpWordpress
from ezhost.ServerDjangoUwsgi import ServerDjangoUwsgi
